[−]Struct beacon::primitives::H32
Fixed 384-bit hash.
Methods
impl H32
pub fn repeat_byte(byte: u8) -> H32
Returns a new fixed hash where all bits are set to the given byte.
pub fn zero() -> H32
Returns a new zero-initialized fixed hash.
pub fn len_bytes() -> usize
Returns the size of this hash in bytes.
pub fn as_bytes(&self) -> &[u8]
Extracts a byte slice containing the entire fixed hash.
pub fn as_bytes_mut(&mut self) -> &mut [u8]
Extracts a mutable byte slice containing the entire fixed hash.
pub fn as_fixed_bytes(&self) -> &[u8; 4]
Extracts a reference to the byte array containing the entire fixed hash.
pub fn as_fixed_bytes_mut(&mut self) -> &mut [u8; 4]
Extracts a reference to the byte array containing the entire fixed hash.
pub fn to_fixed_bytes(self) -> [u8; 4]
Returns the inner bytes array.
pub fn as_ptr(&self) -> *const u8
Returns a constant raw pointer to the value.
pub fn as_mut_ptr(&mut self) -> *mut u8
Returns a mutable raw pointer to the value.
pub fn assign_from_slice(&mut self, src: &[u8])
Assign the bytes from the byte slice src to self.
Note
The given bytes are interpreted in big endian order.
Panics
If the length of src and the number of bytes in self do not match.
pub fn from_slice(src: &[u8]) -> Self
Create a new fixed-hash from the given slice src.
Note
The given bytes are interpreted in big endian order.
Panics
If the length of src and the number of bytes in Self do not match.
pub fn covers(&self, b: &Self) -> bool
Returns true if all bits set in b are also set in self.
pub fn is_zero(&self) -> bool
Returns true if no bits are set.
impl H32
Utilities using the byteorder crate.
pub fn to_low_u64_be(&self) -> u64
Returns the lowest 8 bytes interpreted as big-endian.
Note
For hash type with less than 8 bytes the missing bytes are interpreted as being zero.
pub fn to_low_u64_le(&self) -> u64
Returns the lowest 8 bytes interpreted as little-endian.
Note
For hash type with less than 8 bytes the missing bytes are interpreted as being zero.
pub fn to_low_u64_ne(&self) -> u64
Returns the lowest 8 bytes interpreted as native-endian.
Note
For hash type with less than 8 bytes the missing bytes are interpreted as being zero.
pub fn from_low_u64_be(val: u64) -> Self
Creates a new hash type from the given u64 value.
Note
- The given
u64value is interpreted as big endian. - Ignores the most significant bits of the given value if the hash type has less than 8 bytes.
pub fn from_low_u64_le(val: u64) -> Self
Creates a new hash type from the given u64 value.
Note
- The given
u64value is interpreted as little endian. - Ignores the most significant bits of the given value if the hash type has less than 8 bytes.
pub fn from_low_u64_ne(val: u64) -> Self
Creates a new hash type from the given u64 value.
Note
- The given
u64value is interpreted as native endian. - Ignores the most significant bits of the given value if the hash type has less than 8 bytes.
impl H32
Utilities using the rand crate.
pub fn randomize_using<R: ?Sized>(&mut self, rng: &mut R) where
R: Rng,
R: Rng,
Assign self to a cryptographically random value using the
given random number generator.
pub fn randomize(&mut self)
Assign self to a cryptographically random value.
pub fn random_using<R: ?Sized>(rng: &mut R) -> Self where
R: Rng,
R: Rng,
Create a new hash with cryptographically random content using the given random number generator.
pub fn random() -> Self
Create a new hash with cryptographically random content.